@@ -1,6 +1,8 @@
 describe.irtkd<-function(){
 category <- "dichotomous"
 description  <- "K-Dimensional Item Response Model"
+authors <- c("Ben Goodrich", "Ying Lu")
+year <- 2007
 package <-list(	name 	="MCMCpack",
 		version	="0.6"
 		)
@@ -13,5 +15,5 @@ parameters$pi<-list(equations=c(1,1),
 			varInSpecialFunction=c(2,Inf)
 		)
 			
-list(category=category,description=description,package=package,parameters=parameters)
+list(category = category, authors = authors, year = year,description=description,package=package,parameters=parameters)
 }
